# Common game maths

## About
This package provides access to common math objects that are useful when creating games.

## Why?
I found myself constantly rewriting these classes for each project I was starting, so for simplicity, decided to make them into a package

